#[repr(i32)]pub enum PathTranslation {
Unspecified = 0,
ConstantAddress = 1,
AppendPathToAddress = 2,
}Expand description
Path Translation specifies how to combine the backend address with the request path in order to produce the appropriate forwarding URL for the request.
Path Translation is applicable only to HTTP-based backends. Backends which
do not accept requests over HTTP/HTTPS should leave path_translation
unspecified.
Variants
Unspecified = 0
ConstantAddress = 1
Use the backend address as-is, with no modification to the path. If the URL pattern contains variables, the variable names and values will be appended to the query string. If a query string parameter and a URL pattern variable have the same name, this may result in duplicate keys in the query string.
Examples
Given the following operation config:
Method path: /api/company/{cid}/user/{uid}
Backend address: <https://example.cloudfunctions.net/getUser>Requests to the following request paths will call the backend at the translated path:
Request path: /api/company/widgetworks/user/johndoe
Translated:
<https://example.cloudfunctions.net/getUser?cid=widgetworks&uid=johndoe>
Request path: /api/company/widgetworks/user/johndoe?timezone=EST
Translated:
<https://example.cloudfunctions.net/getUser?timezone=EST&cid=widgetworks&uid=johndoe>AppendPathToAddress = 2
The request path will be appended to the backend address.
Examples
Given the following operation config:
Method path: /api/company/{cid}/user/{uid}
Backend address: <https://example.appspot.com>Requests to the following request paths will call the backend at the translated path:
Request path: /api/company/widgetworks/user/johndoe
Translated:
<https://example.appspot.com/api/company/widgetworks/user/johndoe>
Request path: /api/company/widgetworks/user/johndoe?timezone=EST
Translated:
<https://example.appspot.com/api/company/widgetworks/user/johndoe?timezone=EST>Implementations
Sourceimpl PathTranslation
impl PathTranslation
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.