pub struct Exemplar {
pub value: f64,
pub timestamp: Option<Timestamp>,
pub attachments: Vec<Any>,
}Expand description
Exemplars are example points that may be used to annotate aggregated distribution values. They are metadata that gives information about a particular value added to a Distribution bucket, such as a trace ID that was active when a value was added. They may contain further information, such as a example values and timestamps, origin, etc.
Fields
value: f64Value of the exemplar point. This value determines to which bucket the exemplar belongs.
timestamp: Option<Timestamp>The observation (sampling) time of the above value.
attachments: Vec<Any>Contextual information about the example value. Examples are:
Trace: type.googleapis.com/google.monitoring.v3.SpanContext
Literal string: type.googleapis.com/google.protobuf.StringValue
Labels dropped during aggregation: type.googleapis.com/google.monitoring.v3.DroppedLabels
There may be only a single attachment of any given message type in a single exemplar, and this is enforced by the system.