pub struct Visibility {
pub rules: Vec<VisibilityRule>,
}Expand description
Visibility restricts service consumer’s access to service elements,
such as whether an application can call a visibility-restricted method.
The restriction is expressed by applying visibility labels on service
elements. The visibility labels are elsewhere linked to service consumers.
A service can define multiple visibility labels, but a service consumer should be granted at most one visibility label. Multiple visibility labels for a single service consumer are not supported.
If an element and all its parents have no visibility label, its visibility is unconditionally granted.
Example:
visibility:
rules:
- selector: google.calendar.Calendar.EnhancedSearch
restriction: PREVIEW
- selector: google.calendar.Calendar.Delegate
restriction: INTERNALHere, all methods are publicly visible except for the restricted methods EnhancedSearch and Delegate.
Fields
rules: Vec<VisibilityRule>A list of visibility rules that apply to individual API elements.
NOTE: All service configuration rules follow “last one wins” order.