pub struct DocumentationRule {
pub selector: String,
pub description: String,
pub deprecation_description: String,
}Expand description
A documentation rule provides information about individual API elements.
Fields
selector: StringThe selector is a comma-separated list of patterns for any element such as a method, a field, an enum value. Each pattern is a qualified name of the element which may end in “”, indicating a wildcard. Wildcards are only allowed at the end and for a whole component of the qualified name, i.e. “foo.” is ok, but not “foo.b*” or “foo..bar”. A wildcard will match one or more components. To specify a default for all applicable elements, the whole pattern “” is used.
description: StringDescription of the selected proto element (e.g. a message, a method, a ‘service’ definition, or a field). Defaults to leading & trailing comments taken from the proto source definition of the proto element.
deprecation_description: StringDeprecation description of the selected element(s). It can be provided if
an element is marked as deprecated.